# Academy Tester (Python)

This package contains functions to streamline testing tasks in the [Jetbrains Academy](https://www.jetbrains.com/academy/) plugin available in PyCharm.

Examples of how to use the functions are available.

# Installation

```
pip install academy-tester
```
